# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .transcription_filter import TranscriptionFilter
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProfanityTranscriptionFilter(TranscriptionFilter):
    """
    Profanity transcription filter to recognize profane words.
    """

    #: A constant which can be used with the mode property of a ProfanityTranscriptionFilter.
    #: This constant has a value of "MASK"
    MODE_MASK = "MASK"

    #: A constant which can be used with the mode property of a ProfanityTranscriptionFilter.
    #: This constant has a value of "REMOVE"
    MODE_REMOVE = "REMOVE"

    #: A constant which can be used with the mode property of a ProfanityTranscriptionFilter.
    #: This constant has a value of "TAG"
    MODE_TAG = "TAG"

    def __init__(self, **kwargs):
        """
        Initializes a new ProfanityTranscriptionFilter object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_speech.models.ProfanityTranscriptionFilter.type` attribute
        of this class is ``PROFANITY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ProfanityTranscriptionFilter.
            Allowed values for this property are: "PROFANITY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param mode:
            The value to assign to the mode property of this ProfanityTranscriptionFilter.
            Allowed values for this property are: "MASK", "REMOVE", "TAG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type mode: str

        """
        self.swagger_types = {
            'type': 'str',
            'mode': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'mode': 'mode'
        }

        self._type = None
        self._mode = None
        self._type = 'PROFANITY'

    @property
    def mode(self):
        """
        **[Required]** Gets the mode of this ProfanityTranscriptionFilter.
        - `MASK`: Will mask detected profanity in transcription.
        - `REMOVE`: Will replace profane word with * in transcription.
        - `TAG`: Will tag profane word as profanity but will show actual word.

        Allowed values for this property are: "MASK", "REMOVE", "TAG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The mode of this ProfanityTranscriptionFilter.
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """
        Sets the mode of this ProfanityTranscriptionFilter.
        - `MASK`: Will mask detected profanity in transcription.
        - `REMOVE`: Will replace profane word with * in transcription.
        - `TAG`: Will tag profane word as profanity but will show actual word.


        :param mode: The mode of this ProfanityTranscriptionFilter.
        :type: str
        """
        allowed_values = ["MASK", "REMOVE", "TAG"]
        if not value_allowed_none_or_none_sentinel(mode, allowed_values):
            mode = 'UNKNOWN_ENUM_VALUE'
        self._mode = mode

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeliverArtifactCollection(object):
    """
    Specifies an array of artifacts that need to be pushed to the artifactory stores.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeliverArtifactCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param items:
            The value to assign to the items property of this DeliverArtifactCollection.
        :type items: list[oci.devops.models.DeliverArtifact]

        """
        self.swagger_types = {
            'items': 'list[DeliverArtifact]'
        }

        self.attribute_map = {
            'items': 'items'
        }

        self._items = None

    @property
    def items(self):
        """
        **[Required]** Gets the items of this DeliverArtifactCollection.
        Collection of artifacts that were generated in the Build stage and need to be pushed to the artifactory stores. In case of UPDATE operation, replaces existing artifacts list. Merging with existing artifacts is not supported.


        :return: The items of this DeliverArtifactCollection.
        :rtype: list[oci.devops.models.DeliverArtifact]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this DeliverArtifactCollection.
        Collection of artifacts that were generated in the Build stage and need to be pushed to the artifactory stores. In case of UPDATE operation, replaces existing artifacts list. Merging with existing artifacts is not supported.


        :param items: The items of this DeliverArtifactCollection.
        :type: list[oci.devops.models.DeliverArtifact]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TranscriptionModelDetails(object):
    """
    Model details.
    """

    #: A constant which can be used with the domain property of a TranscriptionModelDetails.
    #: This constant has a value of "GENERIC"
    DOMAIN_GENERIC = "GENERIC"

    #: A constant which can be used with the language_code property of a TranscriptionModelDetails.
    #: This constant has a value of "en-US"
    LANGUAGE_CODE_EN_US = "en-US"

    #: A constant which can be used with the language_code property of a TranscriptionModelDetails.
    #: This constant has a value of "es-ES"
    LANGUAGE_CODE_ES_ES = "es-ES"

    #: A constant which can be used with the language_code property of a TranscriptionModelDetails.
    #: This constant has a value of "pt-BR"
    LANGUAGE_CODE_PT_BR = "pt-BR"

    def __init__(self, **kwargs):
        """
        Initializes a new TranscriptionModelDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param domain:
            The value to assign to the domain property of this TranscriptionModelDetails.
            Allowed values for this property are: "GENERIC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type domain: str

        :param language_code:
            The value to assign to the language_code property of this TranscriptionModelDetails.
            Allowed values for this property are: "en-US", "es-ES", "pt-BR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type language_code: str

        """
        self.swagger_types = {
            'domain': 'str',
            'language_code': 'str'
        }

        self.attribute_map = {
            'domain': 'domain',
            'language_code': 'languageCode'
        }

        self._domain = None
        self._language_code = None

    @property
    def domain(self):
        """
        Gets the domain of this TranscriptionModelDetails.
        Domain for input files.

        Allowed values for this property are: "GENERIC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The domain of this TranscriptionModelDetails.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this TranscriptionModelDetails.
        Domain for input files.


        :param domain: The domain of this TranscriptionModelDetails.
        :type: str
        """
        allowed_values = ["GENERIC"]
        if not value_allowed_none_or_none_sentinel(domain, allowed_values):
            domain = 'UNKNOWN_ENUM_VALUE'
        self._domain = domain

    @property
    def language_code(self):
        """
        Gets the language_code of this TranscriptionModelDetails.
        Locale value as per given in [https://datatracker.ietf.org/doc/html/rfc5646].

        Allowed values for this property are: "en-US", "es-ES", "pt-BR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The language_code of this TranscriptionModelDetails.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """
        Sets the language_code of this TranscriptionModelDetails.
        Locale value as per given in [https://datatracker.ietf.org/doc/html/rfc5646].


        :param language_code: The language_code of this TranscriptionModelDetails.
        :type: str
        """
        allowed_values = ["en-US", "es-ES", "pt-BR"]
        if not value_allowed_none_or_none_sentinel(language_code, allowed_values):
            language_code = 'UNKNOWN_ENUM_VALUE'
        self._language_code = language_code

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .analyze_document_details import AnalyzeDocumentDetails
from .analyze_document_result import AnalyzeDocumentResult
from .analyze_image_details import AnalyzeImageDetails
from .analyze_image_result import AnalyzeImageResult
from .bounding_polygon import BoundingPolygon
from .cell import Cell
from .change_model_compartment_details import ChangeModelCompartmentDetails
from .change_project_compartment_details import ChangeProjectCompartmentDetails
from .create_document_job_details import CreateDocumentJobDetails
from .create_image_job_details import CreateImageJobDetails
from .create_model_details import CreateModelDetails
from .create_project_details import CreateProjectDetails
from .data_science_labeling_dataset import DataScienceLabelingDataset
from .dataset import Dataset
from .detected_document_type import DetectedDocumentType
from .detected_language import DetectedLanguage
from .dimensions import Dimensions
from .document_classification_feature import DocumentClassificationFeature
from .document_details import DocumentDetails
from .document_feature import DocumentFeature
from .document_field import DocumentField
from .document_job import DocumentJob
from .document_key_value_detection_feature import DocumentKeyValueDetectionFeature
from .document_language_classification_feature import DocumentLanguageClassificationFeature
from .document_metadata import DocumentMetadata
from .document_table_detection_feature import DocumentTableDetectionFeature
from .document_text_detection_feature import DocumentTextDetectionFeature
from .field_label import FieldLabel
from .field_name import FieldName
from .field_value import FieldValue
from .image_classification_feature import ImageClassificationFeature
from .image_details import ImageDetails
from .image_feature import ImageFeature
from .image_job import ImageJob
from .image_object import ImageObject
from .image_object_detection_feature import ImageObjectDetectionFeature
from .image_text import ImageText
from .image_text_detection_feature import ImageTextDetectionFeature
from .inline_document_details import InlineDocumentDetails
from .inline_image_details import InlineImageDetails
from .input_location import InputLocation
from .label import Label
from .line import Line
from .model import Model
from .model_collection import ModelCollection
from .model_summary import ModelSummary
from .normalized_vertex import NormalizedVertex
from .object_list_inline_input_location import ObjectListInlineInputLocation
from .object_location import ObjectLocation
from .object_storage_dataset import ObjectStorageDataset
from .object_storage_document_details import ObjectStorageDocumentDetails
from .object_storage_image_details import ObjectStorageImageDetails
from .ontology_class import OntologyClass
from .output_location import OutputLocation
from .page import Page
from .processing_error import ProcessingError
from .project import Project
from .project_collection import ProjectCollection
from .project_summary import ProjectSummary
from .table import Table
from .table_row import TableRow
from .update_model_details import UpdateModelDetails
from .update_project_details import UpdateProjectDetails
from .value_array import ValueArray
from .value_date import ValueDate
from .value_integer import ValueInteger
from .value_number import ValueNumber
from .value_phone_number import ValuePhoneNumber
from .value_string import ValueString
from .value_time import ValueTime
from .word import Word
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for ai_vision services.
ai_vision_type_mapping = {
    "AnalyzeDocumentDetails": AnalyzeDocumentDetails,
    "AnalyzeDocumentResult": AnalyzeDocumentResult,
    "AnalyzeImageDetails": AnalyzeImageDetails,
    "AnalyzeImageResult": AnalyzeImageResult,
    "BoundingPolygon": BoundingPolygon,
    "Cell": Cell,
    "ChangeModelCompartmentDetails": ChangeModelCompartmentDetails,
    "ChangeProjectCompartmentDetails": ChangeProjectCompartmentDetails,
    "CreateDocumentJobDetails": CreateDocumentJobDetails,
    "CreateImageJobDetails": CreateImageJobDetails,
    "CreateModelDetails": CreateModelDetails,
    "CreateProjectDetails": CreateProjectDetails,
    "DataScienceLabelingDataset": DataScienceLabelingDataset,
    "Dataset": Dataset,
    "DetectedDocumentType": DetectedDocumentType,
    "DetectedLanguage": DetectedLanguage,
    "Dimensions": Dimensions,
    "DocumentClassificationFeature": DocumentClassificationFeature,
    "DocumentDetails": DocumentDetails,
    "DocumentFeature": DocumentFeature,
    "DocumentField": DocumentField,
    "DocumentJob": DocumentJob,
    "DocumentKeyValueDetectionFeature": DocumentKeyValueDetectionFeature,
    "DocumentLanguageClassificationFeature": DocumentLanguageClassificationFeature,
    "DocumentMetadata": DocumentMetadata,
    "DocumentTableDetectionFeature": DocumentTableDetectionFeature,
    "DocumentTextDetectionFeature": DocumentTextDetectionFeature,
    "FieldLabel": FieldLabel,
    "FieldName": FieldName,
    "FieldValue": FieldValue,
    "ImageClassificationFeature": ImageClassificationFeature,
    "ImageDetails": ImageDetails,
    "ImageFeature": ImageFeature,
    "ImageJob": ImageJob,
    "ImageObject": ImageObject,
    "ImageObjectDetectionFeature": ImageObjectDetectionFeature,
    "ImageText": ImageText,
    "ImageTextDetectionFeature": ImageTextDetectionFeature,
    "InlineDocumentDetails": InlineDocumentDetails,
    "InlineImageDetails": InlineImageDetails,
    "InputLocation": InputLocation,
    "Label": Label,
    "Line": Line,
    "Model": Model,
    "ModelCollection": ModelCollection,
    "ModelSummary": ModelSummary,
    "NormalizedVertex": NormalizedVertex,
    "ObjectListInlineInputLocation": ObjectListInlineInputLocation,
    "ObjectLocation": ObjectLocation,
    "ObjectStorageDataset": ObjectStorageDataset,
    "ObjectStorageDocumentDetails": ObjectStorageDocumentDetails,
    "ObjectStorageImageDetails": ObjectStorageImageDetails,
    "OntologyClass": OntologyClass,
    "OutputLocation": OutputLocation,
    "Page": Page,
    "ProcessingError": ProcessingError,
    "Project": Project,
    "ProjectCollection": ProjectCollection,
    "ProjectSummary": ProjectSummary,
    "Table": Table,
    "TableRow": TableRow,
    "UpdateModelDetails": UpdateModelDetails,
    "UpdateProjectDetails": UpdateProjectDetails,
    "ValueArray": ValueArray,
    "ValueDate": ValueDate,
    "ValueInteger": ValueInteger,
    "ValueNumber": ValueNumber,
    "ValuePhoneNumber": ValuePhoneNumber,
    "ValueString": ValueString,
    "ValueTime": ValueTime,
    "Word": Word,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .dataset_source_details import DatasetSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectStorageDatasetSourceDetails(DatasetSourceDetails):
    """
    Specifies the dataset location in object storage. This requires that all records are in this bucket, and under this prefix. We do not support a dataset with objects in arbitrary locations across buckets or prefixes.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectStorageDatasetSourceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_labeling_service_dataplane.models.ObjectStorageDatasetSourceDetails.source_type` attribute
        of this class is ``OBJECT_STORAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_type:
            The value to assign to the source_type property of this ObjectStorageDatasetSourceDetails.
            Allowed values for this property are: "OBJECT_STORAGE"
        :type source_type: str

        :param namespace:
            The value to assign to the namespace property of this ObjectStorageDatasetSourceDetails.
        :type namespace: str

        :param bucket:
            The value to assign to the bucket property of this ObjectStorageDatasetSourceDetails.
        :type bucket: str

        :param prefix:
            The value to assign to the prefix property of this ObjectStorageDatasetSourceDetails.
        :type prefix: str

        """
        self.swagger_types = {
            'source_type': 'str',
            'namespace': 'str',
            'bucket': 'str',
            'prefix': 'str'
        }

        self.attribute_map = {
            'source_type': 'sourceType',
            'namespace': 'namespace',
            'bucket': 'bucket',
            'prefix': 'prefix'
        }

        self._source_type = None
        self._namespace = None
        self._bucket = None
        self._prefix = None
        self._source_type = 'OBJECT_STORAGE'

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this ObjectStorageDatasetSourceDetails.
        The namespace of the bucket that contains the dataset data source.


        :return: The namespace of this ObjectStorageDatasetSourceDetails.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this ObjectStorageDatasetSourceDetails.
        The namespace of the bucket that contains the dataset data source.


        :param namespace: The namespace of this ObjectStorageDatasetSourceDetails.
        :type: str
        """
        self._namespace = namespace

    @property
    def bucket(self):
        """
        **[Required]** Gets the bucket of this ObjectStorageDatasetSourceDetails.
        The object storage bucket that contains the dataset data source.


        :return: The bucket of this ObjectStorageDatasetSourceDetails.
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """
        Sets the bucket of this ObjectStorageDatasetSourceDetails.
        The object storage bucket that contains the dataset data source.


        :param bucket: The bucket of this ObjectStorageDatasetSourceDetails.
        :type: str
        """
        self._bucket = bucket

    @property
    def prefix(self):
        """
        Gets the prefix of this ObjectStorageDatasetSourceDetails.
        A common path prefix shared by the objects that make up the dataset. Except for the CSV file type, records are not generated for the objects whose names exactly match with the prefix.


        :return: The prefix of this ObjectStorageDatasetSourceDetails.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this ObjectStorageDatasetSourceDetails.
        A common path prefix shared by the objects that make up the dataset. Except for the CSV file type, records are not generated for the objects whose names exactly match with the prefix.


        :param prefix: The prefix of this ObjectStorageDatasetSourceDetails.
        :type: str
        """
        self._prefix = prefix

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .monitored_resource_credential import MonitoredResourceCredential
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EncryptedCredentials(MonitoredResourceCredential):
    """
    Encypted credentials [indicated by the type property in CredentialStore].
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EncryptedCredentials object with values from keyword arguments. The default value of the :py:attr:`~oci.stack_monitoring.models.EncryptedCredentials.credential_type` attribute
        of this class is ``ENCRYPTED`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this EncryptedCredentials.
        :type source: str

        :param name:
            The value to assign to the name property of this EncryptedCredentials.
        :type name: str

        :param type:
            The value to assign to the type property of this EncryptedCredentials.
        :type type: str

        :param description:
            The value to assign to the description property of this EncryptedCredentials.
        :type description: str

        :param credential_type:
            The value to assign to the credential_type property of this EncryptedCredentials.
            Allowed values for this property are: "EXISTING", "PLAINTEXT", "ENCRYPTED"
        :type credential_type: str

        :param key_id:
            The value to assign to the key_id property of this EncryptedCredentials.
        :type key_id: str

        :param properties:
            The value to assign to the properties property of this EncryptedCredentials.
        :type properties: list[oci.stack_monitoring.models.CredentialProperty]

        """
        self.swagger_types = {
            'source': 'str',
            'name': 'str',
            'type': 'str',
            'description': 'str',
            'credential_type': 'str',
            'key_id': 'str',
            'properties': 'list[CredentialProperty]'
        }

        self.attribute_map = {
            'source': 'source',
            'name': 'name',
            'type': 'type',
            'description': 'description',
            'credential_type': 'credentialType',
            'key_id': 'keyId',
            'properties': 'properties'
        }

        self._source = None
        self._name = None
        self._type = None
        self._description = None
        self._credential_type = None
        self._key_id = None
        self._properties = None
        self._credential_type = 'ENCRYPTED'

    @property
    def key_id(self):
        """
        **[Required]** Gets the key_id of this EncryptedCredentials.
        The master key OCID and applicable only for property value type ENCRYPTION. Key OCID is passed as input to Key management service decrypt API to retrieve the encrypted property value text.


        :return: The key_id of this EncryptedCredentials.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """
        Sets the key_id of this EncryptedCredentials.
        The master key OCID and applicable only for property value type ENCRYPTION. Key OCID is passed as input to Key management service decrypt API to retrieve the encrypted property value text.


        :param key_id: The key_id of this EncryptedCredentials.
        :type: str
        """
        self._key_id = key_id

    @property
    def properties(self):
        """
        **[Required]** Gets the properties of this EncryptedCredentials.
        The credential properties list. Credential property values will be encrypted format.


        :return: The properties of this EncryptedCredentials.
        :rtype: list[oci.stack_monitoring.models.CredentialProperty]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this EncryptedCredentials.
        The credential properties list. Credential property values will be encrypted format.


        :param properties: The properties of this EncryptedCredentials.
        :type: list[oci.stack_monitoring.models.CredentialProperty]
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_build_pipeline_stage_details import CreateBuildPipelineStageDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateWaitStageDetails(CreateBuildPipelineStageDetails):
    """
    Specifies the Wait stage. You can specify variable wait times or an absolute duration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateWaitStageDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.CreateWaitStageDetails.build_pipeline_stage_type` attribute
        of this class is ``WAIT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateWaitStageDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateWaitStageDetails.
        :type description: str

        :param build_pipeline_stage_type:
            The value to assign to the build_pipeline_stage_type property of this CreateWaitStageDetails.
        :type build_pipeline_stage_type: str

        :param build_pipeline_id:
            The value to assign to the build_pipeline_id property of this CreateWaitStageDetails.
        :type build_pipeline_id: str

        :param build_pipeline_stage_predecessor_collection:
            The value to assign to the build_pipeline_stage_predecessor_collection property of this CreateWaitStageDetails.
        :type build_pipeline_stage_predecessor_collection: oci.devops.models.BuildPipelineStagePredecessorCollection

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateWaitStageDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateWaitStageDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param wait_criteria:
            The value to assign to the wait_criteria property of this CreateWaitStageDetails.
        :type wait_criteria: oci.devops.models.CreateWaitCriteriaDetails

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'build_pipeline_stage_type': 'str',
            'build_pipeline_id': 'str',
            'build_pipeline_stage_predecessor_collection': 'BuildPipelineStagePredecessorCollection',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'wait_criteria': 'CreateWaitCriteriaDetails'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'build_pipeline_stage_type': 'buildPipelineStageType',
            'build_pipeline_id': 'buildPipelineId',
            'build_pipeline_stage_predecessor_collection': 'buildPipelineStagePredecessorCollection',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'wait_criteria': 'waitCriteria'
        }

        self._display_name = None
        self._description = None
        self._build_pipeline_stage_type = None
        self._build_pipeline_id = None
        self._build_pipeline_stage_predecessor_collection = None
        self._freeform_tags = None
        self._defined_tags = None
        self._wait_criteria = None
        self._build_pipeline_stage_type = 'WAIT'

    @property
    def wait_criteria(self):
        """
        **[Required]** Gets the wait_criteria of this CreateWaitStageDetails.

        :return: The wait_criteria of this CreateWaitStageDetails.
        :rtype: oci.devops.models.CreateWaitCriteriaDetails
        """
        return self._wait_criteria

    @wait_criteria.setter
    def wait_criteria(self, wait_criteria):
        """
        Sets the wait_criteria of this CreateWaitStageDetails.

        :param wait_criteria: The wait_criteria of this CreateWaitStageDetails.
        :type: oci.devops.models.CreateWaitCriteriaDetails
        """
        self._wait_criteria = wait_criteria

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .resource_principals_federation_signer import ResourcePrincipalsFederationSigner


class ResourcePrincipalsDelegationTokenSigner(ResourcePrincipalsFederationSigner):
    """
        ResourcePrincipalsDelegationTokenSigner extends the functionality of ResourcePrincipalsFederationSigner.
        A delegation token allows the instance to assume the privileges of the user for which the token
        was created.

        :param resource_principal_token_endpoint: The endpoint that can provide the resource principal token.
                                                  This is a service endpoint.

        :param resource_principal_session_token_endpoint: The endpoint that can provide the resource principal session
                                                          token. This will default to the auth federation endpoint
                                                          if not provided.

        :param resource_principal_token_path_provider: An object of a class which implements RptPathProviderInterface
                                                       that can provide the path for resource principal token.
                                                       If not set, use DefaultRptPathProvider to determine the path.

        :param delegation_token : The Delegation token to be used for signing the request.

    """

    def __init__(self, **kwargs):
        self.delegation_token = kwargs['delegation_token']
        generic_headers = ["date", "(request-target)", "host", "opc-obo-token"]
        super(ResourcePrincipalsDelegationTokenSigner, self).__init__(generic_headers=generic_headers, **kwargs)

    # opc-obo-token is added to the request headers
    def do_request_sign(self, request, enforce_content_headers=True):
        request.headers['opc-obo-token'] = self.delegation_token
        super(ResourcePrincipalsDelegationTokenSigner, self).do_request_sign(request, enforce_content_headers)
        return request



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateAdvisorSettings(object):
    """
    Optional Pre-Migration advisor settings.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateAdvisorSettings object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_skip_advisor:
            The value to assign to the is_skip_advisor property of this UpdateAdvisorSettings.
        :type is_skip_advisor: bool

        :param is_ignore_errors:
            The value to assign to the is_ignore_errors property of this UpdateAdvisorSettings.
        :type is_ignore_errors: bool

        """
        self.swagger_types = {
            'is_skip_advisor': 'bool',
            'is_ignore_errors': 'bool'
        }

        self.attribute_map = {
            'is_skip_advisor': 'isSkipAdvisor',
            'is_ignore_errors': 'isIgnoreErrors'
        }

        self._is_skip_advisor = None
        self._is_ignore_errors = None

    @property
    def is_skip_advisor(self):
        """
        Gets the is_skip_advisor of this UpdateAdvisorSettings.
        True to skip the Pre-Migration Advisor execution. Default is false.


        :return: The is_skip_advisor of this UpdateAdvisorSettings.
        :rtype: bool
        """
        return self._is_skip_advisor

    @is_skip_advisor.setter
    def is_skip_advisor(self, is_skip_advisor):
        """
        Sets the is_skip_advisor of this UpdateAdvisorSettings.
        True to skip the Pre-Migration Advisor execution. Default is false.


        :param is_skip_advisor: The is_skip_advisor of this UpdateAdvisorSettings.
        :type: bool
        """
        self._is_skip_advisor = is_skip_advisor

    @property
    def is_ignore_errors(self):
        """
        Gets the is_ignore_errors of this UpdateAdvisorSettings.
        True to not interrupt migration execution due to Pre-Migration Advisor errors. Default is false.


        :return: The is_ignore_errors of this UpdateAdvisorSettings.
        :rtype: bool
        """
        return self._is_ignore_errors

    @is_ignore_errors.setter
    def is_ignore_errors(self, is_ignore_errors):
        """
        Sets the is_ignore_errors of this UpdateAdvisorSettings.
        True to not interrupt migration execution due to Pre-Migration Advisor errors. Default is false.


        :param is_ignore_errors: The is_ignore_errors of this UpdateAdvisorSettings.
        :type: bool
        """
        self._is_ignore_errors = is_ignore_errors

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryResultsGroupedBySummary(object):
    """
    Summary of the attribute based on which the query results are grouped.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryResultsGroupedBySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param query_results_grouped_by_column:
            The value to assign to the query_results_grouped_by_column property of this QueryResultsGroupedBySummary.
        :type query_results_grouped_by_column: str

        """
        self.swagger_types = {
            'query_results_grouped_by_column': 'str'
        }

        self.attribute_map = {
            'query_results_grouped_by_column': 'queryResultsGroupedByColumn'
        }

        self._query_results_grouped_by_column = None

    @property
    def query_results_grouped_by_column(self):
        """
        Gets the query_results_grouped_by_column of this QueryResultsGroupedBySummary.
        Column or attribute in the query result, which is a group by value.


        :return: The query_results_grouped_by_column of this QueryResultsGroupedBySummary.
        :rtype: str
        """
        return self._query_results_grouped_by_column

    @query_results_grouped_by_column.setter
    def query_results_grouped_by_column(self, query_results_grouped_by_column):
        """
        Sets the query_results_grouped_by_column of this QueryResultsGroupedBySummary.
        Column or attribute in the query result, which is a group by value.


        :param query_results_grouped_by_column: The query_results_grouped_by_column of this QueryResultsGroupedBySummary.
        :type: str
        """
        self._query_results_grouped_by_column = query_results_grouped_by_column

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RecordMetadata(object):
    """
    Collection of record's metadata.  This can be, for example, the height, width or depth of image for an image record.
    """

    #: A constant which can be used with the record_type property of a RecordMetadata.
    #: This constant has a value of "IMAGE_METADATA"
    RECORD_TYPE_IMAGE_METADATA = "IMAGE_METADATA"

    #: A constant which can be used with the record_type property of a RecordMetadata.
    #: This constant has a value of "TEXT_METADATA"
    RECORD_TYPE_TEXT_METADATA = "TEXT_METADATA"

    #: A constant which can be used with the record_type property of a RecordMetadata.
    #: This constant has a value of "DOCUMENT_METADATA"
    RECORD_TYPE_DOCUMENT_METADATA = "DOCUMENT_METADATA"

    def __init__(self, **kwargs):
        """
        Initializes a new RecordMetadata object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_labeling_service_dataplane.models.DocumentMetadata`
        * :class:`~oci.data_labeling_service_dataplane.models.ImageMetadata`
        * :class:`~oci.data_labeling_service_dataplane.models.TextMetadata`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param record_type:
            The value to assign to the record_type property of this RecordMetadata.
            Allowed values for this property are: "IMAGE_METADATA", "TEXT_METADATA", "DOCUMENT_METADATA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type record_type: str

        """
        self.swagger_types = {
            'record_type': 'str'
        }

        self.attribute_map = {
            'record_type': 'recordType'
        }

        self._record_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['recordType']

        if type == 'DOCUMENT_METADATA':
            return 'DocumentMetadata'

        if type == 'IMAGE_METADATA':
            return 'ImageMetadata'

        if type == 'TEXT_METADATA':
            return 'TextMetadata'
        else:
            return 'RecordMetadata'

    @property
    def record_type(self):
        """
        Gets the record_type of this RecordMetadata.
        The record type based on dataset format details.
        IMAGE_METADATA  - Collection of metadata related to image record.
        TEXT_METADATA - Collection of metadata related to text record.
        DOCUMENT_METADATA - Collection of metadata related to document record.

        Allowed values for this property are: "IMAGE_METADATA", "TEXT_METADATA", "DOCUMENT_METADATA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The record_type of this RecordMetadata.
        :rtype: str
        """
        return self._record_type

    @record_type.setter
    def record_type(self, record_type):
        """
        Sets the record_type of this RecordMetadata.
        The record type based on dataset format details.
        IMAGE_METADATA  - Collection of metadata related to image record.
        TEXT_METADATA - Collection of metadata related to text record.
        DOCUMENT_METADATA - Collection of metadata related to document record.


        :param record_type: The record_type of this RecordMetadata.
        :type: str
        """
        allowed_values = ["IMAGE_METADATA", "TEXT_METADATA", "DOCUMENT_METADATA"]
        if not value_allowed_none_or_none_sentinel(record_type, allowed_values):
            record_type = 'UNKNOWN_ENUM_VALUE'
        self._record_type = record_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExadataConfigurationSummary(object):
    """
    Summary of a exadata configuration for a resource.
    """

    #: A constant which can be used with the entity_source property of a ExadataConfigurationSummary.
    #: This constant has a value of "EM_MANAGED_EXTERNAL_EXADATA"
    ENTITY_SOURCE_EM_MANAGED_EXTERNAL_EXADATA = "EM_MANAGED_EXTERNAL_EXADATA"

    #: A constant which can be used with the exadata_type property of a ExadataConfigurationSummary.
    #: This constant has a value of "DBMACHINE"
    EXADATA_TYPE_DBMACHINE = "DBMACHINE"

    #: A constant which can be used with the exadata_type property of a ExadataConfigurationSummary.
    #: This constant has a value of "EXACS"
    EXADATA_TYPE_EXACS = "EXACS"

    #: A constant which can be used with the exadata_type property of a ExadataConfigurationSummary.
    #: This constant has a value of "EXACC"
    EXADATA_TYPE_EXACC = "EXACC"

    #: A constant which can be used with the exadata_rack_type property of a ExadataConfigurationSummary.
    #: This constant has a value of "FULL"
    EXADATA_RACK_TYPE_FULL = "FULL"

    #: A constant which can be used with the exadata_rack_type property of a ExadataConfigurationSummary.
    #: This constant has a value of "HALF"
    EXADATA_RACK_TYPE_HALF = "HALF"

    #: A constant which can be used with the exadata_rack_type property of a ExadataConfigurationSummary.
    #: This constant has a value of "QUARTER"
    EXADATA_RACK_TYPE_QUARTER = "QUARTER"

    #: A constant which can be used with the exadata_rack_type property of a ExadataConfigurationSummary.
    #: This constant has a value of "EIGHTH"
    EXADATA_RACK_TYPE_EIGHTH = "EIGHTH"

    def __init__(self, **kwargs):
        """
        Initializes a new ExadataConfigurationSummary object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.opsi.models.ExadataDatabaseMachineConfigurationSummary`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param exadata_insight_id:
            The value to assign to the exadata_insight_id property of this ExadataConfigurationSummary.
        :type exadata_insight_id: str

        :param entity_source:
            The value to assign to the entity_source property of this ExadataConfigurationSummary.
            Allowed values for this property are: "EM_MANAGED_EXTERNAL_EXADATA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_source: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ExadataConfigurationSummary.
        :type compartment_id: str

        :param exadata_name:
            The value to assign to the exadata_name property of this ExadataConfigurationSummary.
        :type exadata_name: str

        :param exadata_display_name:
            The value to assign to the exadata_display_name property of this ExadataConfigurationSummary.
        :type exadata_display_name: str

        :param exadata_type:
            The value to assign to the exadata_type property of this ExadataConfigurationSummary.
            Allowed values for this property are: "DBMACHINE", "EXACS", "EXACC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type exadata_type: str

        :param exadata_rack_type:
            The value to assign to the exadata_rack_type property of this ExadataConfigurationSummary.
            Allowed values for this property are: "FULL", "HALF", "QUARTER", "EIGHTH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type exadata_rack_type: str

        :param defined_tags:
            The value to assign to the defined_tags property of this ExadataConfigurationSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ExadataConfigurationSummary.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'exadata_insight_id': 'str',
            'entity_source': 'str',
            'compartment_id': 'str',
            'exadata_name': 'str',
            'exadata_display_name': 'str',
            'exadata_type': 'str',
            'exadata_rack_type': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'exadata_insight_id': 'exadataInsightId',
            'entity_source': 'entitySource',
            'compartment_id': 'compartmentId',
            'exadata_name': 'exadataName',
            'exadata_display_name': 'exadataDisplayName',
            'exadata_type': 'exadataType',
            'exadata_rack_type': 'exadataRackType',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._exadata_insight_id = None
        self._entity_source = None
        self._compartment_id = None
        self._exadata_name = None
        self._exadata_display_name = None
        self._exadata_type = None
        self._exadata_rack_type = None
        self._defined_tags = None
        self._freeform_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['entitySource']

        if type == 'EM_MANAGED_EXTERNAL_EXADATA':
            return 'ExadataDatabaseMachineConfigurationSummary'
        else:
            return 'ExadataConfigurationSummary'

    @property
    def exadata_insight_id(self):
        """
        **[Required]** Gets the exadata_insight_id of this ExadataConfigurationSummary.
        The `OCID`__ of the Exadata insight.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The exadata_insight_id of this ExadataConfigurationSummary.
        :rtype: str
        """
        return self._exadata_insight_id

    @exadata_insight_id.setter
    def exadata_insight_id(self, exadata_insight_id):
        """
        Sets the exadata_insight_id of this ExadataConfigurationSummary.
        The `OCID`__ of the Exadata insight.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param exadata_insight_id: The exadata_insight_id of this ExadataConfigurationSummary.
        :type: str
        """
        self._exadata_insight_id = exadata_insight_id

    @property
    def entity_source(self):
        """
        **[Required]** Gets the entity_source of this ExadataConfigurationSummary.
        Source of the exadata entity.

        Allowed values for this property are: "EM_MANAGED_EXTERNAL_EXADATA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The entity_source of this ExadataConfigurationSummary.
        :rtype: str
        """
        return self._entity_source

    @entity_source.setter
    def entity_source(self, entity_source):
        """
        Sets the entity_source of this ExadataConfigurationSummary.
        Source of the exadata entity.


        :param entity_source: The entity_source of this ExadataConfigurationSummary.
        :type: str
        """
        allowed_values = ["EM_MANAGED_EXTERNAL_EXADATA"]
        if not value_allowed_none_or_none_sentinel(entity_source, allowed_values):
            entity_source = 'UNKNOWN_ENUM_VALUE'
        self._entity_source = entity_source

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ExadataConfigurationSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ExadataConfigurationSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ExadataConfigurationSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ExadataConfigurationSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def exadata_name(self):
        """
        **[Required]** Gets the exadata_name of this ExadataConfigurationSummary.
        The Exadata system name. If the Exadata systems managed by Enterprise Manager, the name is unique amongst the Exadata systems managed by the same Enterprise Manager.


        :return: The exadata_name of this ExadataConfigurationSummary.
        :rtype: str
        """
        return self._exadata_name

    @exadata_name.setter
    def exadata_name(self, exadata_name):
        """
        Sets the exadata_name of this ExadataConfigurationSummary.
        The Exadata system name. If the Exadata systems managed by Enterprise Manager, the name is unique amongst the Exadata systems managed by the same Enterprise Manager.


        :param exadata_name: The exadata_name of this ExadataConfigurationSummary.
        :type: str
        """
        self._exadata_name = exadata_name

    @property
    def exadata_display_name(self):
        """
        **[Required]** Gets the exadata_display_name of this ExadataConfigurationSummary.
        The user-friendly name for the Exadata system. The name does not have to be unique.


        :return: The exadata_display_name of this ExadataConfigurationSummary.
        :rtype: str
        """
        return self._exadata_display_name

    @exadata_display_name.setter
    def exadata_display_name(self, exadata_display_name):
        """
        Sets the exadata_display_name of this ExadataConfigurationSummary.
        The user-friendly name for the Exadata system. The name does not have to be unique.


        :param exadata_display_name: The exadata_display_name of this ExadataConfigurationSummary.
        :type: str
        """
        self._exadata_display_name = exadata_display_name

    @property
    def exadata_type(self):
        """
        **[Required]** Gets the exadata_type of this ExadataConfigurationSummary.
        Operations Insights internal representation of the the Exadata system type.

        Allowed values for this property are: "DBMACHINE", "EXACS", "EXACC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The exadata_type of this ExadataConfigurationSummary.
        :rtype: str
        """
        return self._exadata_type

    @exadata_type.setter
    def exadata_type(self, exadata_type):
        """
        Sets the exadata_type of this ExadataConfigurationSummary.
        Operations Insights internal representation of the the Exadata system type.


        :param exadata_type: The exadata_type of this ExadataConfigurationSummary.
        :type: str
        """
        allowed_values = ["DBMACHINE", "EXACS", "EXACC"]
        if not value_allowed_none_or_none_sentinel(exadata_type, allowed_values):
            exadata_type = 'UNKNOWN_ENUM_VALUE'
        self._exadata_type = exadata_type

    @property
    def exadata_rack_type(self):
        """
        **[Required]** Gets the exadata_rack_type of this ExadataConfigurationSummary.
        Exadata rack type.

        Allowed values for this property are: "FULL", "HALF", "QUARTER", "EIGHTH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The exadata_rack_type of this ExadataConfigurationSummary.
        :rtype: str
        """
        return self._exadata_rack_type

    @exadata_rack_type.setter
    def exadata_rack_type(self, exadata_rack_type):
        """
        Sets the exadata_rack_type of this ExadataConfigurationSummary.
        Exadata rack type.


        :param exadata_rack_type: The exadata_rack_type of this ExadataConfigurationSummary.
        :type: str
        """
        allowed_values = ["FULL", "HALF", "QUARTER", "EIGHTH"]
        if not value_allowed_none_or_none_sentinel(exadata_rack_type, allowed_values):
            exadata_rack_type = 'UNKNOWN_ENUM_VALUE'
        self._exadata_rack_type = exadata_rack_type

    @property
    def defined_tags(self):
        """
        **[Required]** Gets the defined_tags of this ExadataConfigurationSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this ExadataConfigurationSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ExadataConfigurationSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this ExadataConfigurationSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        **[Required]** Gets the freeform_tags of this ExadataConfigurationSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this ExadataConfigurationSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ExadataConfigurationSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this ExadataConfigurationSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResizeDataFileDetails(object):
    """
    The details required to resize a data file or temp file within the tablespace.
    """

    #: A constant which can be used with the file_type property of a ResizeDataFileDetails.
    #: This constant has a value of "DATAFILE"
    FILE_TYPE_DATAFILE = "DATAFILE"

    #: A constant which can be used with the file_type property of a ResizeDataFileDetails.
    #: This constant has a value of "TEMPFILE"
    FILE_TYPE_TEMPFILE = "TEMPFILE"

    def __init__(self, **kwargs):
        """
        Initializes a new ResizeDataFileDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param credential_details:
            The value to assign to the credential_details property of this ResizeDataFileDetails.
        :type credential_details: oci.database_management.models.TablespaceAdminCredentialDetails

        :param file_type:
            The value to assign to the file_type property of this ResizeDataFileDetails.
            Allowed values for this property are: "DATAFILE", "TEMPFILE"
        :type file_type: str

        :param data_file:
            The value to assign to the data_file property of this ResizeDataFileDetails.
        :type data_file: str

        :param file_size:
            The value to assign to the file_size property of this ResizeDataFileDetails.
        :type file_size: oci.database_management.models.TablespaceStorageSize

        :param is_auto_extensible:
            The value to assign to the is_auto_extensible property of this ResizeDataFileDetails.
        :type is_auto_extensible: bool

        :param auto_extend_next_size:
            The value to assign to the auto_extend_next_size property of this ResizeDataFileDetails.
        :type auto_extend_next_size: oci.database_management.models.TablespaceStorageSize

        :param auto_extend_max_size:
            The value to assign to the auto_extend_max_size property of this ResizeDataFileDetails.
        :type auto_extend_max_size: oci.database_management.models.TablespaceStorageSize

        :param is_max_size_unlimited:
            The value to assign to the is_max_size_unlimited property of this ResizeDataFileDetails.
        :type is_max_size_unlimited: bool

        """
        self.swagger_types = {
            'credential_details': 'TablespaceAdminCredentialDetails',
            'file_type': 'str',
            'data_file': 'str',
            'file_size': 'TablespaceStorageSize',
            'is_auto_extensible': 'bool',
            'auto_extend_next_size': 'TablespaceStorageSize',
            'auto_extend_max_size': 'TablespaceStorageSize',
            'is_max_size_unlimited': 'bool'
        }

        self.attribute_map = {
            'credential_details': 'credentialDetails',
            'file_type': 'fileType',
            'data_file': 'dataFile',
            'file_size': 'fileSize',
            'is_auto_extensible': 'isAutoExtensible',
            'auto_extend_next_size': 'autoExtendNextSize',
            'auto_extend_max_size': 'autoExtendMaxSize',
            'is_max_size_unlimited': 'isMaxSizeUnlimited'
        }

        self._credential_details = None
        self._file_type = None
        self._data_file = None
        self._file_size = None
        self._is_auto_extensible = None
        self._auto_extend_next_size = None
        self._auto_extend_max_size = None
        self._is_max_size_unlimited = None

    @property
    def credential_details(self):
        """
        **[Required]** Gets the credential_details of this ResizeDataFileDetails.

        :return: The credential_details of this ResizeDataFileDetails.
        :rtype: oci.database_management.models.TablespaceAdminCredentialDetails
        """
        return self._credential_details

    @credential_details.setter
    def credential_details(self, credential_details):
        """
        Sets the credential_details of this ResizeDataFileDetails.

        :param credential_details: The credential_details of this ResizeDataFileDetails.
        :type: oci.database_management.models.TablespaceAdminCredentialDetails
        """
        self._credential_details = credential_details

    @property
    def file_type(self):
        """
        **[Required]** Gets the file_type of this ResizeDataFileDetails.
        Specifies whether the file is a data file or temp file.

        Allowed values for this property are: "DATAFILE", "TEMPFILE"


        :return: The file_type of this ResizeDataFileDetails.
        :rtype: str
        """
        return self._file_type

    @file_type.setter
    def file_type(self, file_type):
        """
        Sets the file_type of this ResizeDataFileDetails.
        Specifies whether the file is a data file or temp file.


        :param file_type: The file_type of this ResizeDataFileDetails.
        :type: str
        """
        allowed_values = ["DATAFILE", "TEMPFILE"]
        if not value_allowed_none_or_none_sentinel(file_type, allowed_values):
            raise ValueError(
                "Invalid value for `file_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._file_type = file_type

    @property
    def data_file(self):
        """
        **[Required]** Gets the data_file of this ResizeDataFileDetails.
        Name of the data file or temp file to be resized.


        :return: The data_file of this ResizeDataFileDetails.
        :rtype: str
        """
        return self._data_file

    @data_file.setter
    def data_file(self, data_file):
        """
        Sets the data_file of this ResizeDataFileDetails.
        Name of the data file or temp file to be resized.


        :param data_file: The data_file of this ResizeDataFileDetails.
        :type: str
        """
        self._data_file = data_file

    @property
    def file_size(self):
        """
        Gets the file_size of this ResizeDataFileDetails.
        The new size of the data file or temp file.


        :return: The file_size of this ResizeDataFileDetails.
        :rtype: oci.database_management.models.TablespaceStorageSize
        """
        return self._file_size

    @file_size.setter
    def file_size(self, file_size):
        """
        Sets the file_size of this ResizeDataFileDetails.
        The new size of the data file or temp file.


        :param file_size: The file_size of this ResizeDataFileDetails.
        :type: oci.database_management.models.TablespaceStorageSize
        """
        self._file_size = file_size

    @property
    def is_auto_extensible(self):
        """
        Gets the is_auto_extensible of this ResizeDataFileDetails.
        Specifies whether the data file or temp file can be extended automatically.


        :return: The is_auto_extensible of this ResizeDataFileDetails.
        :rtype: bool
        """
        return self._is_auto_extensible

    @is_auto_extensible.setter
    def is_auto_extensible(self, is_auto_extensible):
        """
        Sets the is_auto_extensible of this ResizeDataFileDetails.
        Specifies whether the data file or temp file can be extended automatically.


        :param is_auto_extensible: The is_auto_extensible of this ResizeDataFileDetails.
        :type: bool
        """
        self._is_auto_extensible = is_auto_extensible

    @property
    def auto_extend_next_size(self):
        """
        Gets the auto_extend_next_size of this ResizeDataFileDetails.
        The size of the next increment of disk space to be allocated automatically when more extents are required.


        :return: The auto_extend_next_size of this ResizeDataFileDetails.
        :rtype: oci.database_management.models.TablespaceStorageSize
        """
        return self._auto_extend_next_size

    @auto_extend_next_size.setter
    def auto_extend_next_size(self, auto_extend_next_size):
        """
        Sets the auto_extend_next_size of this ResizeDataFileDetails.
        The size of the next increment of disk space to be allocated automatically when more extents are required.


        :param auto_extend_next_size: The auto_extend_next_size of this ResizeDataFileDetails.
        :type: oci.database_management.models.TablespaceStorageSize
        """
        self._auto_extend_next_size = auto_extend_next_size

    @property
    def auto_extend_max_size(self):
        """
        Gets the auto_extend_max_size of this ResizeDataFileDetails.
        The maximum disk space allowed for automatic extension of the data files or temp files.


        :return: The auto_extend_max_size of this ResizeDataFileDetails.
        :rtype: oci.database_management.models.TablespaceStorageSize
        """
        return self._auto_extend_max_size

    @auto_extend_max_size.setter
    def auto_extend_max_size(self, auto_extend_max_size):
        """
        Sets the auto_extend_max_size of this ResizeDataFileDetails.
        The maximum disk space allowed for automatic extension of the data files or temp files.


        :param auto_extend_max_size: The auto_extend_max_size of this ResizeDataFileDetails.
        :type: oci.database_management.models.TablespaceStorageSize
        """
        self._auto_extend_max_size = auto_extend_max_size

    @property
    def is_max_size_unlimited(self):
        """
        Gets the is_max_size_unlimited of this ResizeDataFileDetails.
        Specifies whether the disk space of the data file or temp file can be limited.


        :return: The is_max_size_unlimited of this ResizeDataFileDetails.
        :rtype: bool
        """
        return self._is_max_size_unlimited

    @is_max_size_unlimited.setter
    def is_max_size_unlimited(self, is_max_size_unlimited):
        """
        Sets the is_max_size_unlimited of this ResizeDataFileDetails.
        Specifies whether the disk space of the data file or temp file can be limited.


        :param is_max_size_unlimited: The is_max_size_unlimited of this ResizeDataFileDetails.
        :type: bool
        """
        self._is_max_size_unlimited = is_max_size_unlimited

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .backup_location import BackupLocation
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BackupLocationBucket(BackupLocation):
    """
    Object storage bucket details to upload or download the backup
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BackupLocationBucket object with values from keyword arguments. The default value of the :py:attr:`~oci.key_management.models.BackupLocationBucket.destination` attribute
        of this class is ``BUCKET`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param destination:
            The value to assign to the destination property of this BackupLocationBucket.
            Allowed values for this property are: "BUCKET", "PRE_AUTHENTICATED_REQUEST_URI"
        :type destination: str

        :param namespace:
            The value to assign to the namespace property of this BackupLocationBucket.
        :type namespace: str

        :param bucket_name:
            The value to assign to the bucket_name property of this BackupLocationBucket.
        :type bucket_name: str

        :param object_name:
            The value to assign to the object_name property of this BackupLocationBucket.
        :type object_name: str

        """
        self.swagger_types = {
            'destination': 'str',
            'namespace': 'str',
            'bucket_name': 'str',
            'object_name': 'str'
        }

        self.attribute_map = {
            'destination': 'destination',
            'namespace': 'namespace',
            'bucket_name': 'bucketName',
            'object_name': 'objectName'
        }

        self._destination = None
        self._namespace = None
        self._bucket_name = None
        self._object_name = None
        self._destination = 'BUCKET'

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this BackupLocationBucket.

        :return: The namespace of this BackupLocationBucket.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this BackupLocationBucket.

        :param namespace: The namespace of this BackupLocationBucket.
        :type: str
        """
        self._namespace = namespace

    @property
    def bucket_name(self):
        """
        **[Required]** Gets the bucket_name of this BackupLocationBucket.

        :return: The bucket_name of this BackupLocationBucket.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this BackupLocationBucket.

        :param bucket_name: The bucket_name of this BackupLocationBucket.
        :type: str
        """
        self._bucket_name = bucket_name

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this BackupLocationBucket.

        :return: The object_name of this BackupLocationBucket.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this BackupLocationBucket.

        :param object_name: The object_name of this BackupLocationBucket.
        :type: str
        """
        self._object_name = object_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApplicationDetails(object):
    """
    The information about the application.
    """

    #: A constant which can be used with the lifecycle_state property of a ApplicationDetails.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ApplicationDetails.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ApplicationDetails.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ApplicationDetails.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ApplicationDetails.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ApplicationDetails.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new ApplicationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this ApplicationDetails.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this ApplicationDetails.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this ApplicationDetails.
        :type model_version: str

        :param name:
            The value to assign to the name property of this ApplicationDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this ApplicationDetails.
        :type description: str

        :param application_version:
            The value to assign to the application_version property of this ApplicationDetails.
        :type application_version: int

        :param object_status:
            The value to assign to the object_status property of this ApplicationDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this ApplicationDetails.
        :type identifier: str

        :param parent_ref:
            The value to assign to the parent_ref property of this ApplicationDetails.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param object_version:
            The value to assign to the object_version property of this ApplicationDetails.
        :type object_version: int

        :param metadata:
            The value to assign to the metadata property of this ApplicationDetails.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param display_name:
            The value to assign to the display_name property of this ApplicationDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ApplicationDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ApplicationDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ApplicationDetails.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'application_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'parent_ref': 'ParentReference',
            'object_version': 'int',
            'metadata': 'ObjectMetadata',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'application_version': 'applicationVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parent_ref': 'parentRef',
            'object_version': 'objectVersion',
            'metadata': 'metadata',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'lifecycle_state': 'lifecycleState'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._name = None
        self._description = None
        self._application_version = None
        self._object_status = None
        self._identifier = None
        self._parent_ref = None
        self._object_version = None
        self._metadata = None
        self._display_name = None
        self._freeform_tags = None
        self._defined_tags = None
        self._lifecycle_state = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this ApplicationDetails.
        Generated key that can be used in API calls to identify application.


        :return: The key of this ApplicationDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ApplicationDetails.
        Generated key that can be used in API calls to identify application.


        :param key: The key of this ApplicationDetails.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this ApplicationDetails.
        The object type.


        :return: The model_type of this ApplicationDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this ApplicationDetails.
        The object type.


        :param model_type: The model_type of this ApplicationDetails.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this ApplicationDetails.
        The object's model version.


        :return: The model_version of this ApplicationDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this ApplicationDetails.
        The object's model version.


        :param model_version: The model_version of this ApplicationDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        Gets the name of this ApplicationDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this ApplicationDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ApplicationDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this ApplicationDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ApplicationDetails.
        Detailed description for the object.


        :return: The description of this ApplicationDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ApplicationDetails.
        Detailed description for the object.


        :param description: The description of this ApplicationDetails.
        :type: str
        """
        self._description = description

    @property
    def application_version(self):
        """
        Gets the application_version of this ApplicationDetails.
        version


        :return: The application_version of this ApplicationDetails.
        :rtype: int
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """
        Sets the application_version of this ApplicationDetails.
        version


        :param application_version: The application_version of this ApplicationDetails.
        :type: int
        """
        self._application_version = application_version

    @property
    def object_status(self):
        """
        Gets the object_status of this ApplicationDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this ApplicationDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this ApplicationDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this ApplicationDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this ApplicationDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this ApplicationDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this ApplicationDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this ApplicationDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this ApplicationDetails.

        :return: The parent_ref of this ApplicationDetails.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this ApplicationDetails.

        :param parent_ref: The parent_ref of this ApplicationDetails.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def object_version(self):
        """
        **[Required]** Gets the object_version of this ApplicationDetails.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this ApplicationDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this ApplicationDetails.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this ApplicationDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def metadata(self):
        """
        Gets the metadata of this ApplicationDetails.

        :return: The metadata of this ApplicationDetails.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this ApplicationDetails.

        :param metadata: The metadata of this ApplicationDetails.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    @property
    def display_name(self):
        """
        Gets the display_name of this ApplicationDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The display_name of this ApplicationDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ApplicationDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param display_name: The display_name of this ApplicationDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ApplicationDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this ApplicationDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ApplicationDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this ApplicationDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ApplicationDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this ApplicationDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ApplicationDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this ApplicationDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this ApplicationDetails.
        The current state of the workspace.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"


        :return: The lifecycle_state of this ApplicationDetails.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ApplicationDetails.
        The current state of the workspace.


        :param lifecycle_state: The lifecycle_state of this ApplicationDetails.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            raise ValueError(
                "Invalid value for `lifecycle_state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PaymentOption(object):
    """
    Payment option of a subscription.
    """

    #: A constant which can be used with the payment_method property of a PaymentOption.
    #: This constant has a value of "CREDIT_CARD"
    PAYMENT_METHOD_CREDIT_CARD = "CREDIT_CARD"

    #: A constant which can be used with the payment_method property of a PaymentOption.
    #: This constant has a value of "PAYPAL"
    PAYMENT_METHOD_PAYPAL = "PAYPAL"

    def __init__(self, **kwargs):
        """
        Initializes a new PaymentOption object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.osp_gateway.models.CreditCardPaymentOption`
        * :class:`~oci.osp_gateway.models.PaypalPaymentOption`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param wallet_instrument_id:
            The value to assign to the wallet_instrument_id property of this PaymentOption.
        :type wallet_instrument_id: str

        :param wallet_transaction_id:
            The value to assign to the wallet_transaction_id property of this PaymentOption.
        :type wallet_transaction_id: str

        :param payment_method:
            The value to assign to the payment_method property of this PaymentOption.
            Allowed values for this property are: "CREDIT_CARD", "PAYPAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type payment_method: str

        """
        self.swagger_types = {
            'wallet_instrument_id': 'str',
            'wallet_transaction_id': 'str',
            'payment_method': 'str'
        }

        self.attribute_map = {
            'wallet_instrument_id': 'walletInstrumentId',
            'wallet_transaction_id': 'walletTransactionId',
            'payment_method': 'paymentMethod'
        }

        self._wallet_instrument_id = None
        self._wallet_transaction_id = None
        self._payment_method = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['paymentMethod']

        if type == 'CREDIT_CARD':
            return 'CreditCardPaymentOption'

        if type == 'PAYPAL':
            return 'PaypalPaymentOption'
        else:
            return 'PaymentOption'

    @property
    def wallet_instrument_id(self):
        """
        Gets the wallet_instrument_id of this PaymentOption.
        Wallet instrument internal id.


        :return: The wallet_instrument_id of this PaymentOption.
        :rtype: str
        """
        return self._wallet_instrument_id

    @wallet_instrument_id.setter
    def wallet_instrument_id(self, wallet_instrument_id):
        """
        Sets the wallet_instrument_id of this PaymentOption.
        Wallet instrument internal id.


        :param wallet_instrument_id: The wallet_instrument_id of this PaymentOption.
        :type: str
        """
        self._wallet_instrument_id = wallet_instrument_id

    @property
    def wallet_transaction_id(self):
        """
        Gets the wallet_transaction_id of this PaymentOption.
        Wallet transaction id.


        :return: The wallet_transaction_id of this PaymentOption.
        :rtype: str
        """
        return self._wallet_transaction_id

    @wallet_transaction_id.setter
    def wallet_transaction_id(self, wallet_transaction_id):
        """
        Sets the wallet_transaction_id of this PaymentOption.
        Wallet transaction id.


        :param wallet_transaction_id: The wallet_transaction_id of this PaymentOption.
        :type: str
        """
        self._wallet_transaction_id = wallet_transaction_id

    @property
    def payment_method(self):
        """
        **[Required]** Gets the payment_method of this PaymentOption.
        Payment method

        Allowed values for this property are: "CREDIT_CARD", "PAYPAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The payment_method of this PaymentOption.
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """
        Sets the payment_method of this PaymentOption.
        Payment method


        :param payment_method: The payment_method of this PaymentOption.
        :type: str
        """
        allowed_values = ["CREDIT_CARD", "PAYPAL"]
        if not value_allowed_none_or_none_sentinel(payment_method, allowed_values):
            payment_method = 'UNKNOWN_ENUM_VALUE'
        self._payment_method = payment_method

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDataAssetDetails(object):
    """
    Properties used in data asset Create operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDataAssetDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this CreateDataAssetDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateDataAssetDetails.
        :type model_version: str

        :param model_type:
            The value to assign to the model_type property of this CreateDataAssetDetails.
        :type model_type: str

        :param name:
            The value to assign to the name property of this CreateDataAssetDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateDataAssetDetails.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this CreateDataAssetDetails.
        :type object_status: int

        :param object_version:
            The value to assign to the object_version property of this CreateDataAssetDetails.
        :type object_version: int

        :param identifier:
            The value to assign to the identifier property of this CreateDataAssetDetails.
        :type identifier: str

        :param external_key:
            The value to assign to the external_key property of this CreateDataAssetDetails.
        :type external_key: str

        :param asset_properties:
            The value to assign to the asset_properties property of this CreateDataAssetDetails.
        :type asset_properties: dict(str, str)

        :param properties:
            The value to assign to the properties property of this CreateDataAssetDetails.
        :type properties: dict(str, object)

        :param type:
            The value to assign to the type property of this CreateDataAssetDetails.
        :type type: str

        :param native_type_system:
            The value to assign to the native_type_system property of this CreateDataAssetDetails.
        :type native_type_system: oci.data_connectivity.models.TypeSystem

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreateDataAssetDetails.
        :type registry_metadata: oci.data_connectivity.models.RegistryMetadata

        :param metadata:
            The value to assign to the metadata property of this CreateDataAssetDetails.
        :type metadata: oci.data_connectivity.models.ObjectMetadata

        :param default_connection:
            The value to assign to the default_connection property of this CreateDataAssetDetails.
        :type default_connection: oci.data_connectivity.models.Connection

        :param end_points:
            The value to assign to the end_points property of this CreateDataAssetDetails.
        :type end_points: list[oci.data_connectivity.models.DpEndpoint]

        """
        self.swagger_types = {
            'key': 'str',
            'model_version': 'str',
            'model_type': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'object_version': 'int',
            'identifier': 'str',
            'external_key': 'str',
            'asset_properties': 'dict(str, str)',
            'properties': 'dict(str, object)',
            'type': 'str',
            'native_type_system': 'TypeSystem',
            'registry_metadata': 'RegistryMetadata',
            'metadata': 'ObjectMetadata',
            'default_connection': 'Connection',
            'end_points': 'list[DpEndpoint]'
        }

        self.attribute_map = {
            'key': 'key',
            'model_version': 'modelVersion',
            'model_type': 'modelType',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'object_version': 'objectVersion',
            'identifier': 'identifier',
            'external_key': 'externalKey',
            'asset_properties': 'assetProperties',
            'properties': 'properties',
            'type': 'type',
            'native_type_system': 'nativeTypeSystem',
            'registry_metadata': 'registryMetadata',
            'metadata': 'metadata',
            'default_connection': 'defaultConnection',
            'end_points': 'endPoints'
        }

        self._key = None
        self._model_version = None
        self._model_type = None
        self._name = None
        self._description = None
        self._object_status = None
        self._object_version = None
        self._identifier = None
        self._external_key = None
        self._asset_properties = None
        self._properties = None
        self._type = None
        self._native_type_system = None
        self._registry_metadata = None
        self._metadata = None
        self._default_connection = None
        self._end_points = None

    @property
    def key(self):
        """
        Gets the key of this CreateDataAssetDetails.
        Generated key that can be used in API calls to identify dataasset.


        :return: The key of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this CreateDataAssetDetails.
        Generated key that can be used in API calls to identify dataasset.


        :param key: The key of this CreateDataAssetDetails.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this CreateDataAssetDetails.
        The model version of an object.


        :return: The model_version of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this CreateDataAssetDetails.
        The model version of an object.


        :param model_version: The model_version of this CreateDataAssetDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def model_type(self):
        """
        Gets the model_type of this CreateDataAssetDetails.
        The type of the object.


        :return: The model_type of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this CreateDataAssetDetails.
        The type of the object.


        :param model_type: The model_type of this CreateDataAssetDetails.
        :type: str
        """
        self._model_type = model_type

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateDataAssetDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateDataAssetDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this CreateDataAssetDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CreateDataAssetDetails.
        User-defined description of the data asset.


        :return: The description of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateDataAssetDetails.
        User-defined description of the data asset.


        :param description: The description of this CreateDataAssetDetails.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this CreateDataAssetDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this CreateDataAssetDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this CreateDataAssetDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this CreateDataAssetDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def object_version(self):
        """
        Gets the object_version of this CreateDataAssetDetails.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this CreateDataAssetDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this CreateDataAssetDetails.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this CreateDataAssetDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this CreateDataAssetDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this CreateDataAssetDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this CreateDataAssetDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def external_key(self):
        """
        Gets the external_key of this CreateDataAssetDetails.
        The external key for the object.


        :return: The external_key of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this CreateDataAssetDetails.
        The external key for the object.


        :param external_key: The external_key of this CreateDataAssetDetails.
        :type: str
        """
        self._external_key = external_key

    @property
    def asset_properties(self):
        """
        Gets the asset_properties of this CreateDataAssetDetails.
        Additional properties for the data asset.


        :return: The asset_properties of this CreateDataAssetDetails.
        :rtype: dict(str, str)
        """
        return self._asset_properties

    @asset_properties.setter
    def asset_properties(self, asset_properties):
        """
        Sets the asset_properties of this CreateDataAssetDetails.
        Additional properties for the data asset.


        :param asset_properties: The asset_properties of this CreateDataAssetDetails.
        :type: dict(str, str)
        """
        self._asset_properties = asset_properties

    @property
    def properties(self):
        """
        **[Required]** Gets the properties of this CreateDataAssetDetails.
        All the properties for the data asset in a key-value map format.


        :return: The properties of this CreateDataAssetDetails.
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this CreateDataAssetDetails.
        All the properties for the data asset in a key-value map format.


        :param properties: The properties of this CreateDataAssetDetails.
        :type: dict(str, object)
        """
        self._properties = properties

    @property
    def type(self):
        """
        **[Required]** Gets the type of this CreateDataAssetDetails.
        Specific DataAsset Type


        :return: The type of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CreateDataAssetDetails.
        Specific DataAsset Type


        :param type: The type of this CreateDataAssetDetails.
        :type: str
        """
        self._type = type

    @property
    def native_type_system(self):
        """
        Gets the native_type_system of this CreateDataAssetDetails.

        :return: The native_type_system of this CreateDataAssetDetails.
        :rtype: oci.data_connectivity.models.TypeSystem
        """
        return self._native_type_system

    @native_type_system.setter
    def native_type_system(self, native_type_system):
        """
        Sets the native_type_system of this CreateDataAssetDetails.

        :param native_type_system: The native_type_system of this CreateDataAssetDetails.
        :type: oci.data_connectivity.models.TypeSystem
        """
        self._native_type_system = native_type_system

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this CreateDataAssetDetails.

        :return: The registry_metadata of this CreateDataAssetDetails.
        :rtype: oci.data_connectivity.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this CreateDataAssetDetails.

        :param registry_metadata: The registry_metadata of this CreateDataAssetDetails.
        :type: oci.data_connectivity.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    @property
    def metadata(self):
        """
        Gets the metadata of this CreateDataAssetDetails.

        :return: The metadata of this CreateDataAssetDetails.
        :rtype: oci.data_connectivity.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this CreateDataAssetDetails.

        :param metadata: The metadata of this CreateDataAssetDetails.
        :type: oci.data_connectivity.models.ObjectMetadata
        """
        self._metadata = metadata

    @property
    def default_connection(self):
        """
        Gets the default_connection of this CreateDataAssetDetails.

        :return: The default_connection of this CreateDataAssetDetails.
        :rtype: oci.data_connectivity.models.Connection
        """
        return self._default_connection

    @default_connection.setter
    def default_connection(self, default_connection):
        """
        Sets the default_connection of this CreateDataAssetDetails.

        :param default_connection: The default_connection of this CreateDataAssetDetails.
        :type: oci.data_connectivity.models.Connection
        """
        self._default_connection = default_connection

    @property
    def end_points(self):
        """
        Gets the end_points of this CreateDataAssetDetails.
        The list of endpoints with which this data asset is associated.


        :return: The end_points of this CreateDataAssetDetails.
        :rtype: list[oci.data_connectivity.models.DpEndpoint]
        """
        return self._end_points

    @end_points.setter
    def end_points(self, end_points):
        """
        Sets the end_points of this CreateDataAssetDetails.
        The list of endpoints with which this data asset is associated.


        :param end_points: The end_points of this CreateDataAssetDetails.
        :type: list[oci.data_connectivity.models.DpEndpoint]
        """
        self._end_points = end_points

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StatementsAggregateMetrics(object):
    """
    The queued and running statement metrics for Autonomous Databases.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StatementsAggregateMetrics object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param queued_statements:
            The value to assign to the queued_statements property of this StatementsAggregateMetrics.
        :type queued_statements: oci.database_management.models.MetricDataPoint

        :param running_statements:
            The value to assign to the running_statements property of this StatementsAggregateMetrics.
        :type running_statements: oci.database_management.models.MetricDataPoint

        """
        self.swagger_types = {
            'queued_statements': 'MetricDataPoint',
            'running_statements': 'MetricDataPoint'
        }

        self.attribute_map = {
            'queued_statements': 'queuedStatements',
            'running_statements': 'runningStatements'
        }

        self._queued_statements = None
        self._running_statements = None

    @property
    def queued_statements(self):
        """
        Gets the queued_statements of this StatementsAggregateMetrics.

        :return: The queued_statements of this StatementsAggregateMetrics.
        :rtype: oci.database_management.models.MetricDataPoint
        """
        return self._queued_statements

    @queued_statements.setter
    def queued_statements(self, queued_statements):
        """
        Sets the queued_statements of this StatementsAggregateMetrics.

        :param queued_statements: The queued_statements of this StatementsAggregateMetrics.
        :type: oci.database_management.models.MetricDataPoint
        """
        self._queued_statements = queued_statements

    @property
    def running_statements(self):
        """
        Gets the running_statements of this StatementsAggregateMetrics.

        :return: The running_statements of this StatementsAggregateMetrics.
        :rtype: oci.database_management.models.MetricDataPoint
        """
        return self._running_statements

    @running_statements.setter
    def running_statements(self, running_statements):
        """
        Sets the running_statements of this StatementsAggregateMetrics.

        :param running_statements: The running_statements of this StatementsAggregateMetrics.
        :type: oci.database_management.models.MetricDataPoint
        """
        self._running_statements = running_statements

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CertificateAuthoritySummary(object):
    """
    The metadata details of the certificate authority (CA). This summary object does not contain the CA contents.
    """

    #: A constant which can be used with the lifecycle_state property of a CertificateAuthoritySummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a CertificateAuthoritySummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a CertificateAuthoritySummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a CertificateAuthoritySummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a CertificateAuthoritySummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a CertificateAuthoritySummary.
    #: This constant has a value of "SCHEDULING_DELETION"
    LIFECYCLE_STATE_SCHEDULING_DELETION = "SCHEDULING_DELETION"

    #: A constant which can be used with the lifecycle_state property of a CertificateAuthoritySummary.
    #: This constant has a value of "PENDING_DELETION"
    LIFECYCLE_STATE_PENDING_DELETION = "PENDING_DELETION"

    #: A constant which can be used with the lifecycle_state property of a CertificateAuthoritySummary.
    #: This constant has a value of "CANCELLING_DELETION"
    LIFECYCLE_STATE_CANCELLING_DELETION = "CANCELLING_DELETION"

    #: A constant which can be used with the lifecycle_state property of a CertificateAuthoritySummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the config_type property of a CertificateAuthoritySummary.
    #: This constant has a value of "ROOT_CA_GENERATED_INTERNALLY"
    CONFIG_TYPE_ROOT_CA_GENERATED_INTERNALLY = "ROOT_CA_GENERATED_INTERNALLY"

    #: A constant which can be used with the config_type property of a CertificateAuthoritySummary.
    #: This constant has a value of "SUBORDINATE_CA_ISSUED_BY_INTERNAL_CA"
    CONFIG_TYPE_SUBORDINATE_CA_ISSUED_BY_INTERNAL_CA = "SUBORDINATE_CA_ISSUED_BY_INTERNAL_CA"

    #: A constant which can be used with the signing_algorithm property of a CertificateAuthoritySummary.
    #: This constant has a value of "SHA256_WITH_RSA"
    SIGNING_ALGORITHM_SHA256_WITH_RSA = "SHA256_WITH_RSA"

    #: A constant which can be used with the signing_algorithm property of a CertificateAuthoritySummary.
    #: This constant has a value of "SHA384_WITH_RSA"
    SIGNING_ALGORITHM_SHA384_WITH_RSA = "SHA384_WITH_RSA"

    #: A constant which can be used with the signing_algorithm property of a CertificateAuthoritySummary.
    #: This constant has a value of "SHA512_WITH_RSA"
    SIGNING_ALGORITHM_SHA512_WITH_RSA = "SHA512_WITH_RSA"

    #: A constant which can be used with the signing_algorithm property of a CertificateAuthoritySummary.
    #: This constant has a value of "SHA256_WITH_ECDSA"
    SIGNING_ALGORITHM_SHA256_WITH_ECDSA = "SHA256_WITH_ECDSA"

    #: A constant which can be used with the signing_algorithm property of a CertificateAuthoritySummary.
    #: This constant has a value of "SHA384_WITH_ECDSA"
    SIGNING_ALGORITHM_SHA384_WITH_ECDSA = "SHA384_WITH_ECDSA"

    #: A constant which can be used with the signing_algorithm property of a CertificateAuthoritySummary.
    #: This constant has a value of "SHA512_WITH_ECDSA"
    SIGNING_ALGORITHM_SHA512_WITH_ECDSA = "SHA512_WITH_ECDSA"

    def __init__(self, **kwargs):
        """
        Initializes a new CertificateAuthoritySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CertificateAuthoritySummary.
        :type id: str

        :param issuer_certificate_authority_id:
            The value to assign to the issuer_certificate_authority_id property of this CertificateAuthoritySummary.
        :type issuer_certificate_authority_id: str

        :param name:
            The value to assign to the name property of this CertificateAuthoritySummary.
        :type name: str

        :param description:
            The value to assign to the description property of this CertificateAuthoritySummary.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this CertificateAuthoritySummary.
        :type time_created: datetime

        :param time_of_deletion:
            The value to assign to the time_of_deletion property of this CertificateAuthoritySummary.
        :type time_of_deletion: datetime

        :param kms_key_id:
            The value to assign to the kms_key_id property of this CertificateAuthoritySummary.
        :type kms_key_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CertificateAuthoritySummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "SCHEDULING_DELETION", "PENDING_DELETION", "CANCELLING_DELETION", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CertificateAuthoritySummary.
        :type compartment_id: str

        :param certificate_authority_rules:
            The value to assign to the certificate_authority_rules property of this CertificateAuthoritySummary.
        :type certificate_authority_rules: list[oci.certificates_management.models.CertificateAuthorityRule]

        :param current_version_summary:
            The value to assign to the current_version_summary property of this CertificateAuthoritySummary.
        :type current_version_summary: oci.certificates_management.models.CertificateAuthorityVersionSummary

        :param subject:
            The value to assign to the subject property of this CertificateAuthoritySummary.
        :type subject: oci.certificates_management.models.CertificateSubject

        :param config_type:
            The value to assign to the config_type property of this CertificateAuthoritySummary.
            Allowed values for this property are: "ROOT_CA_GENERATED_INTERNALLY", "SUBORDINATE_CA_ISSUED_BY_INTERNAL_CA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type config_type: str

        :param signing_algorithm:
            The value to assign to the signing_algorithm property of this CertificateAuthoritySummary.
            Allowed values for this property are: "SHA256_WITH_RSA", "SHA384_WITH_RSA", "SHA512_WITH_RSA", "SHA256_WITH_ECDSA", "SHA384_WITH_ECDSA", "SHA512_WITH_ECDSA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type signing_algorithm: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CertificateAuthoritySummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CertificateAuthoritySummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'issuer_certificate_authority_id': 'str',
            'name': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'time_of_deletion': 'datetime',
            'kms_key_id': 'str',
            'lifecycle_state': 'str',
            'compartment_id': 'str',
            'certificate_authority_rules': 'list[CertificateAuthorityRule]',
            'current_version_summary': 'CertificateAuthorityVersionSummary',
            'subject': 'CertificateSubject',
            'config_type': 'str',
            'signing_algorithm': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'issuer_certificate_authority_id': 'issuerCertificateAuthorityId',
            'name': 'name',
            'description': 'description',
            'time_created': 'timeCreated',
            'time_of_deletion': 'timeOfDeletion',
            'kms_key_id': 'kmsKeyId',
            'lifecycle_state': 'lifecycleState',
            'compartment_id': 'compartmentId',
            'certificate_authority_rules': 'certificateAuthorityRules',
            'current_version_summary': 'currentVersionSummary',
            'subject': 'subject',
            'config_type': 'configType',
            'signing_algorithm': 'signingAlgorithm',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._issuer_certificate_authority_id = None
        self._name = None
        self._description = None
        self._time_created = None
        self._time_of_deletion = None
        self._kms_key_id = None
        self._lifecycle_state = None
        self._compartment_id = None
        self._certificate_authority_rules = None
        self._current_version_summary = None
        self._subject = None
        self._config_type = None
        self._signing_algorithm = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this CertificateAuthoritySummary.
        The OCID of the certificate authority (CA).


        :return: The id of this CertificateAuthoritySummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CertificateAuthoritySummary.
        The OCID of the certificate authority (CA).


        :param id: The id of this CertificateAuthoritySummary.
        :type: str
        """
        self._id = id

    @property
    def issuer_certificate_authority_id(self):
        """
        Gets the issuer_certificate_authority_id of this CertificateAuthoritySummary.
        The OCID of the parent CA which issued this CA. If this is the root CA, then this value is the same as the `id`.


        :return: The issuer_certificate_authority_id of this CertificateAuthoritySummary.
        :rtype: str
        """
        return self._issuer_certificate_authority_id

    @issuer_certificate_authority_id.setter
    def issuer_certificate_authority_id(self, issuer_certificate_authority_id):
        """
        Sets the issuer_certificate_authority_id of this CertificateAuthoritySummary.
        The OCID of the parent CA which issued this CA. If this is the root CA, then this value is the same as the `id`.


        :param issuer_certificate_authority_id: The issuer_certificate_authority_id of this CertificateAuthoritySummary.
        :type: str
        """
        self._issuer_certificate_authority_id = issuer_certificate_authority_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CertificateAuthoritySummary.
        A user-friendly name for the CA. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        :return: The name of this CertificateAuthoritySummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CertificateAuthoritySummary.
        A user-friendly name for the CA. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        :param name: The name of this CertificateAuthoritySummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CertificateAuthoritySummary.
        A brief description of the CA.


        :return: The description of this CertificateAuthoritySummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CertificateAuthoritySummary.
        A brief description of the CA.


        :param description: The description of this CertificateAuthoritySummary.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this CertificateAuthoritySummary.
        A property indicating when the CA was created, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this CertificateAuthoritySummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this CertificateAuthoritySummary.
        A property indicating when the CA was created, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this CertificateAuthoritySummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_of_deletion(self):
        """
        Gets the time_of_deletion of this CertificateAuthoritySummary.
        An optional property indicating when to delete the CA version, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_deletion of this CertificateAuthoritySummary.
        :rtype: datetime
        """
        return self._time_of_deletion

    @time_of_deletion.setter
    def time_of_deletion(self, time_of_deletion):
        """
        Sets the time_of_deletion of this CertificateAuthoritySummary.
        An optional property indicating when to delete the CA version, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_deletion: The time_of_deletion of this CertificateAuthoritySummary.
        :type: datetime
        """
        self._time_of_deletion = time_of_deletion

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this CertificateAuthoritySummary.
        The OCID of the Oracle Cloud Infrastructure Vault key used to encrypt the CA.


        :return: The kms_key_id of this CertificateAuthoritySummary.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this CertificateAuthoritySummary.
        The OCID of the Oracle Cloud Infrastructure Vault key used to encrypt the CA.


        :param kms_key_id: The kms_key_id of this CertificateAuthoritySummary.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this CertificateAuthoritySummary.
        The current lifecycle state of the CA.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "SCHEDULING_DELETION", "PENDING_DELETION", "CANCELLING_DELETION", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this CertificateAuthoritySummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this CertificateAuthoritySummary.
        The current lifecycle state of the CA.


        :param lifecycle_state: The lifecycle_state of this CertificateAuthoritySummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "SCHEDULING_DELETION", "PENDING_DELETION", "CANCELLING_DELETION", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CertificateAuthoritySummary.
        The OCID of the compartment under which the CA is created.


        :return: The compartment_id of this CertificateAuthoritySummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CertificateAuthoritySummary.
        The OCID of the compartment under which the CA is created.


        :param compartment_id: The compartment_id of this CertificateAuthoritySummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def certificate_authority_rules(self):
        """
        Gets the certificate_authority_rules of this CertificateAuthoritySummary.
        An optional list of rules that control how the CA is used and managed.


        :return: The certificate_authority_rules of this CertificateAuthoritySummary.
        :rtype: list[oci.certificates_management.models.CertificateAuthorityRule]
        """
        return self._certificate_authority_rules

    @certificate_authority_rules.setter
    def certificate_authority_rules(self, certificate_authority_rules):
        """
        Sets the certificate_authority_rules of this CertificateAuthoritySummary.
        An optional list of rules that control how the CA is used and managed.


        :param certificate_authority_rules: The certificate_authority_rules of this CertificateAuthoritySummary.
        :type: list[oci.certificates_management.models.CertificateAuthorityRule]
        """
        self._certificate_authority_rules = certificate_authority_rules

    @property
    def current_version_summary(self):
        """
        Gets the current_version_summary of this CertificateAuthoritySummary.

        :return: The current_version_summary of this CertificateAuthoritySummary.
        :rtype: oci.certificates_management.models.CertificateAuthorityVersionSummary
        """
        return self._current_version_summary

    @current_version_summary.setter
    def current_version_summary(self, current_version_summary):
        """
        Sets the current_version_summary of this CertificateAuthoritySummary.

        :param current_version_summary: The current_version_summary of this CertificateAuthoritySummary.
        :type: oci.certificates_management.models.CertificateAuthorityVersionSummary
        """
        self._current_version_summary = current_version_summary

    @property
    def subject(self):
        """
        Gets the subject of this CertificateAuthoritySummary.

        :return: The subject of this CertificateAuthoritySummary.
        :rtype: oci.certificates_management.models.CertificateSubject
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this CertificateAuthoritySummary.

        :param subject: The subject of this CertificateAuthoritySummary.
        :type: oci.certificates_management.models.CertificateSubject
        """
        self._subject = subject

    @property
    def config_type(self):
        """
        **[Required]** Gets the config_type of this CertificateAuthoritySummary.
        The origin of the CA.

        Allowed values for this property are: "ROOT_CA_GENERATED_INTERNALLY", "SUBORDINATE_CA_ISSUED_BY_INTERNAL_CA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The config_type of this CertificateAuthoritySummary.
        :rtype: str
        """
        return self._config_type

    @config_type.setter
    def config_type(self, config_type):
        """
        Sets the config_type of this CertificateAuthoritySummary.
        The origin of the CA.


        :param config_type: The config_type of this CertificateAuthoritySummary.
        :type: str
        """
        allowed_values = ["ROOT_CA_GENERATED_INTERNALLY", "SUBORDINATE_CA_ISSUED_BY_INTERNAL_CA"]
        if not value_allowed_none_or_none_sentinel(config_type, allowed_values):
            config_type = 'UNKNOWN_ENUM_VALUE'
        self._config_type = config_type

    @property
    def signing_algorithm(self):
        """
        Gets the signing_algorithm of this CertificateAuthoritySummary.
        The algorithm used to sign public key certificates that the CA issues.

        Allowed values for this property are: "SHA256_WITH_RSA", "SHA384_WITH_RSA", "SHA512_WITH_RSA", "SHA256_WITH_ECDSA", "SHA384_WITH_ECDSA", "SHA512_WITH_ECDSA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The signing_algorithm of this CertificateAuthoritySummary.
        :rtype: str
        """
        return self._signing_algorithm

    @signing_algorithm.setter
    def signing_algorithm(self, signing_algorithm):
        """
        Sets the signing_algorithm of this CertificateAuthoritySummary.
        The algorithm used to sign public key certificates that the CA issues.


        :param signing_algorithm: The signing_algorithm of this CertificateAuthoritySummary.
        :type: str
        """
        allowed_values = ["SHA256_WITH_RSA", "SHA384_WITH_RSA", "SHA512_WITH_RSA", "SHA256_WITH_ECDSA", "SHA384_WITH_ECDSA", "SHA512_WITH_ECDSA"]
        if not value_allowed_none_or_none_sentinel(signing_algorithm, allowed_values):
            signing_algorithm = 'UNKNOWN_ENUM_VALUE'
        self._signing_algorithm = signing_algorithm

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CertificateAuthoritySummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CertificateAuthoritySummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CertificateAuthoritySummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CertificateAuthoritySummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CertificateAuthoritySummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CertificateAuthoritySummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CertificateAuthoritySummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CertificateAuthoritySummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InclusionCriterionSummary(object):
    """
    Summary of the inclusion criterion.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InclusionCriterionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this InclusionCriterionSummary.
        :type id: str

        :param governance_rule_id:
            The value to assign to the governance_rule_id property of this InclusionCriterionSummary.
        :type governance_rule_id: str

        :param type:
            The value to assign to the type property of this InclusionCriterionSummary.
        :type type: str

        :param association:
            The value to assign to the association property of this InclusionCriterionSummary.
        :type association: oci.governance_rules_control_plane.models.Association

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this InclusionCriterionSummary.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this InclusionCriterionSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this InclusionCriterionSummary.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'governance_rule_id': 'str',
            'type': 'str',
            'association': 'Association',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'governance_rule_id': 'governanceRuleId',
            'type': 'type',
            'association': 'association',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._id = None
        self._governance_rule_id = None
        self._type = None
        self._association = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this InclusionCriterionSummary.
        The Oracle ID (`OCID`__) of the inclusion criterion.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this InclusionCriterionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this InclusionCriterionSummary.
        The Oracle ID (`OCID`__) of the inclusion criterion.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this InclusionCriterionSummary.
        :type: str
        """
        self._id = id

    @property
    def governance_rule_id(self):
        """
        **[Required]** Gets the governance_rule_id of this InclusionCriterionSummary.
        The Oracle ID (`OCID`__) of the governance rule. Every inclusion criterion is associated with a governance rule.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The governance_rule_id of this InclusionCriterionSummary.
        :rtype: str
        """
        return self._governance_rule_id

    @governance_rule_id.setter
    def governance_rule_id(self, governance_rule_id):
        """
        Sets the governance_rule_id of this InclusionCriterionSummary.
        The Oracle ID (`OCID`__) of the governance rule. Every inclusion criterion is associated with a governance rule.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param governance_rule_id: The governance_rule_id of this InclusionCriterionSummary.
        :type: str
        """
        self._governance_rule_id = governance_rule_id

    @property
    def type(self):
        """
        **[Required]** Gets the type of this InclusionCriterionSummary.
        Type of inclusion criterion - TENANCY, ALL or TAG. We support TENANCY and ALL for now.


        :return: The type of this InclusionCriterionSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this InclusionCriterionSummary.
        Type of inclusion criterion - TENANCY, ALL or TAG. We support TENANCY and ALL for now.


        :param type: The type of this InclusionCriterionSummary.
        :type: str
        """
        self._type = type

    @property
    def association(self):
        """
        Gets the association of this InclusionCriterionSummary.

        :return: The association of this InclusionCriterionSummary.
        :rtype: oci.governance_rules_control_plane.models.Association
        """
        return self._association

    @association.setter
    def association(self, association):
        """
        Sets the association of this InclusionCriterionSummary.

        :param association: The association of this InclusionCriterionSummary.
        :type: oci.governance_rules_control_plane.models.Association
        """
        self._association = association

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this InclusionCriterionSummary.
        The current state of the inclusion criterion.


        :return: The lifecycle_state of this InclusionCriterionSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this InclusionCriterionSummary.
        The current state of the inclusion criterion.


        :param lifecycle_state: The lifecycle_state of this InclusionCriterionSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this InclusionCriterionSummary.
        Date and time the inclusion criterion was created. An RFC3339 formatted datetime string.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this InclusionCriterionSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this InclusionCriterionSummary.
        Date and time the inclusion criterion was created. An RFC3339 formatted datetime string.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this InclusionCriterionSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this InclusionCriterionSummary.
        Date and time the inclusion criterion was updated. An RFC3339 formatted datetime string.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_updated of this InclusionCriterionSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this InclusionCriterionSummary.
        Date and time the inclusion criterion was updated. An RFC3339 formatted datetime string.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_updated: The time_updated of this InclusionCriterionSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseToolsRelatedResourceMySql(object):
    """
    A related resource
    """

    #: A constant which can be used with the entity_type property of a DatabaseToolsRelatedResourceMySql.
    #: This constant has a value of "MYSQLDBSYSTEM"
    ENTITY_TYPE_MYSQLDBSYSTEM = "MYSQLDBSYSTEM"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseToolsRelatedResourceMySql object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_type:
            The value to assign to the entity_type property of this DatabaseToolsRelatedResourceMySql.
            Allowed values for this property are: "MYSQLDBSYSTEM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_type: str

        :param identifier:
            The value to assign to the identifier property of this DatabaseToolsRelatedResourceMySql.
        :type identifier: str

        """
        self.swagger_types = {
            'entity_type': 'str',
            'identifier': 'str'
        }

        self.attribute_map = {
            'entity_type': 'entityType',
            'identifier': 'identifier'
        }

        self._entity_type = None
        self._identifier = None

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this DatabaseToolsRelatedResourceMySql.
        The resource entity type.

        Allowed values for this property are: "MYSQLDBSYSTEM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The entity_type of this DatabaseToolsRelatedResourceMySql.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this DatabaseToolsRelatedResourceMySql.
        The resource entity type.


        :param entity_type: The entity_type of this DatabaseToolsRelatedResourceMySql.
        :type: str
        """
        allowed_values = ["MYSQLDBSYSTEM"]
        if not value_allowed_none_or_none_sentinel(entity_type, allowed_values):
            entity_type = 'UNKNOWN_ENUM_VALUE'
        self._entity_type = entity_type

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this DatabaseToolsRelatedResourceMySql.
        The `OCID`__ of the related resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The identifier of this DatabaseToolsRelatedResourceMySql.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this DatabaseToolsRelatedResourceMySql.
        The `OCID`__ of the related resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param identifier: The identifier of this DatabaseToolsRelatedResourceMySql.
        :type: str
        """
        self._identifier = identifier

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_deployment_details import UpdateDeploymentDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDeployPipelineDeploymentDetails(UpdateDeploymentDetails):
    """
    Update details for a pipeline deployment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDeployPipelineDeploymentDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.UpdateDeployPipelineDeploymentDetails.deployment_type` attribute
        of this class is ``PIPELINE_DEPLOYMENT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deployment_type:
            The value to assign to the deployment_type property of this UpdateDeployPipelineDeploymentDetails.
        :type deployment_type: str

        :param display_name:
            The value to assign to the display_name property of this UpdateDeployPipelineDeploymentDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateDeployPipelineDeploymentDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateDeployPipelineDeploymentDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'deployment_type': 'str',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'deployment_type': 'deploymentType',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._deployment_type = None
        self._display_name = None
        self._freeform_tags = None
        self._defined_tags = None
        self._deployment_type = 'PIPELINE_DEPLOYMENT'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
